@@ -1,14 +1,9 @@
-import json
-from typing import Any, Dict, Optional
+from typing import Any, Dict
 
-conductors_dict: Optional[Dict[str, Any]] = None
+from .conductors import conductors_dict
 
 
 def get_by_name(conductor_name: str) -> Dict[str, Any]:
-    global conductors_dict
-    if conductors_dict is None:
-        with open('conductor_data.json') as f:
-            conductors_dict = json.load(f)
     return conductors_dict[conductor_name]
 
 
